import 'dart:io';
import 'package:comet_cli/config.dart';
import 'package:comet_cli/gh_pages.dart';
import 'package:comet_cli/read_yaml.dart';
import 'package:comet_cli/run_flutter_release_build.dart';
import 'package:comet_cli/utils/progress_star.dart';

Future<void> deploy() async {
  // Cometプロジェクトかどうか
  final cometYaml = readCometYaml();
  if (cometYaml == null) {
    print('Not found $cometYamlName');
    return;
  }

  final githubUserId = cometYaml.github.userId;
  final githubRepoName = cometYaml.github.repoName;
  if (githubUserId == null) {
    print('github.user_id が設定されていません');
    return;
  }

  if (githubRepoName == null) {
    print('github.repo_name が設定されていません');
    return;
  }

  ProgressStar.start();

  // comet build
  await Process.run(
    'comet',
    [
      'build',
    ],
    runInShell: true,
  );

  // Flutter ビルド
  await runFlutterReleaseBuild(
    cometYaml.flutterProject.root,
    githubRepoName,
  );

  // Git リポジトリかどうか
  final ghPages = GHPages(flutterProject: cometYaml.flutterProject.root);
  final isGitdir = await ghPages.isGitDir();

  if (!isGitdir) {
    // Gitリポジトリではないのでinit
    print('git init...');
    await ghPages.gitInit();
  }

  // リモートリポジトリを持っているか
  final hasRemote = await ghPages.hasRemote();

  if (!hasRemote) {
    // リモートリポジトリを持っていないのでadd
    print('git remote add origin...');
    await ghPages.addOrigin(
      githubUserId,
      githubRepoName,
    );
  }

  // gh-pages ブランチにコミット
  await ghPages.commitGHBranch();

  // gh-pages ブランチをプッシュ
  await ghPages.pushGHBranch();
  ProgressStar.stop();

  print('完了 以下のURLにサイトが公開されました (数分かかります)');
  print('https://$githubUserId.github.io/$githubRepoName/');
}
