import 'dart:io';
import 'package:comet_cli/config.dart';
import 'package:comet_cli/utils/progress_star.dart';
import 'package:comet_cli/read_yaml.dart';
import 'package:comet_cli/resolve_src_shelves.dart';
import 'package:comet_cli/run_flutter_run.dart';
import 'package:comet_cli/watch_to_restart.dart';

Future<void> start() async {
  // Cometプロジェクトかどうか
  final cometYaml = readCometYaml();
  if (cometYaml == null) {
    print('Not found $cometYamlName');
    return;
  }

  ProgressStar.start();

  await _runCometBuild();

  final process = await runFlutterRun(
    cometYaml.flutterProject.root,
    () {
      // on app finished
      ProgressStar.stop();
      exit(0);
    },
    () {
      // maybe app started
      ProgressStar.blink();
    },
  );

  final foldersToWatch = await resolveSrcShelves(cometYaml);
  watchToRestart(foldersToWatch, process);
}

Future<void> _runCometBuild() async {
  await Process.run(
    'comet',
    [
      'build',
    ],
    runInShell: true,
  );
}
