import 'dart:io';
import 'package:comet_cli/config.dart';
import 'package:comet_cli/types/yaml.dart';
import 'package:yaml/yaml.dart';

CometYaml? readCometYaml() {
  final file = File(cometYamlName);
  final exists = file.existsSync();
  if (!exists) return null;
  final text = file.readAsStringSync();
  final yaml = loadYaml(text) as Map;

  /* site */
  final site = yaml['site'] as Map;
  final tabbarIcon = site['icon'] as String;
  final tabbarTitle = site['title'] as String;
  final copyright = site['copyright'] as String;

  final yamlSite = CometYamlSite(
    icon: tabbarIcon,
    title: tabbarTitle,
    copyright: copyright,
  );

  /* github */
  final github = yaml['github'] as Map;
  final githubUserId = github['user_id'] as String?;
  final githubRepoName = github['repo_name'] as String?;

  final yamlGithub = CometYamlGithub(
    userId: githubUserId,
    repoName: githubRepoName,
  );

  /* flutter_project */
  final flutterProject = yaml['flutter_project'] as Map;
  final root = flutterProject['root'] as String;

  final yamlFlutterProject = CometYamlFlutterProject(
    root: root,
  );

  /* fonts */
  final fonts = yaml['fonts'] as List;

  final yamlFonts = fonts.map((it) {
    final url = it['url'] as String;
    final font = it['font'] as String;
    return CometYamlFont(
      url: url,
      font: font,
    );
  }).toList();

  return CometYaml(
    site: yamlSite,
    github: yamlGithub,
    flutterProject: yamlFlutterProject,
    fonts: yamlFonts,
  );
}
