import 'dart:convert';
import 'dart:io';
import 'package:comet_cli/run_flutter.dart';
import 'package:comet_cli/run_flutter_restart.dart';
import 'package:watcher/watcher.dart';

// - onMaybeLaunched: アプリ起動の目安 将来のFlutterの変更で壊れるかもしれない
Future<Process> runFlutterRun(
  String project,
  void Function() onExit,
  void Function() onMaybeLaunched,
) async {
  final process = await runFlutter(
    project,
    const [
      'run',
      '-d',
      'chrome',
    ],
  );

  const watcherDelay = Duration(seconds: 1);
  final watcher = DirectoryWatcher(
    '$project${Platform.pathSeparator}lib',
    pollingDelay: watcherDelay,
  );
  watcher.events.listen((change) async {
    if (change.type == ChangeType.MODIFY) {
      await runFlutterRestart(process);
    }
  });

  // 通常のログを監視
  process.stdout.listen((data) {
    final msg = utf8.decode(data, allowMalformed: true);
    // アプリ起動を判断するためのキーワード
    const keyword = 'The Flutter DevTools';
    if (msg.startsWith(keyword)) {
      onMaybeLaunched();
    }
    stdout.write(msg);
  });

  // エラーのログを監視
  process.stderr.listen((data) {
    final msg = utf8.decode(data, allowMalformed: true);
    stdout.write(msg);
  });

  process.exitCode.then((_) => onExit());
  return process;
}
