import 'dart:async';
import 'dart:io';
import 'package:comet_cli/commands/build_for_edit.dart';
import 'package:comet_cli/run_flutter_restart.dart';
import 'package:watcher/watcher.dart';

List<StreamSubscription<WatchEvent>> watchToRestart(
  List<String> folders,
  Process process,
) {
  // mdファイルの変更を監視
  final List<StreamSubscription<WatchEvent>> subsList = [];
  const watcherDelay = Duration(seconds: 1);
  for (final folder in folders) {
    final watcher = DirectoryWatcher(
      folder,
      pollingDelay: watcherDelay,
    );
    final subs = watcher.events.listen((change) async {
      if (change.type == ChangeType.MODIFY) {
        stdout.write('Edit: ${change.path}');
        await buildForEdit(change.path);
        await runFlutterRestart(process);
      }
      if (change.type == ChangeType.ADD) {
        stdout.write('New: ${change.path}');
        await _runCometBuild();
        await runFlutterRestart(process);
      }
      if (change.type == ChangeType.REMOVE) {
        stdout.write('Deleted: ${change.path}');
        await _runCometBuild();
        await runFlutterRestart(process);
      }
    });
    subsList.add(subs);
  }
  return subsList;
}

Future<void> _runCometBuild() async {
  await Process.run(
    'comet',
    [
      'build',
    ],
    runInShell: true,
  );
}
